@@ -1,28 +1,36 @@
 package resources
 
 import (
+	"context"
+	"time"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/apigatewayv2"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type APIGatewayV2API struct {
-	svc          *apigatewayv2.ApiGatewayV2
-	v2APIID      *string
-	name         *string
-	protocolType *string
-	version      *string
-	tags         map[string]*string
-}
+const APIGatewayV2APIResource = "APIGatewayV2API"
 
 func init() {
-	register("APIGatewayV2API", ListAPIGatewayV2APIs)
+	registry.Register(&registry.Registration{
+		Name:     APIGatewayV2APIResource,
+		Scope:    nuke.Account,
+		Resource: &APIGatewayV2API{},
+		Lister:   &APIGatewayV2APILister{},
+	})
 }
 
-func ListAPIGatewayV2APIs(sess *session.Session) ([]Resource, error) {
-	svc := apigatewayv2.New(sess)
-	resources := []Resource{}
+type APIGatewayV2APILister struct{}
+
+func (l *APIGatewayV2APILister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+	svc := apigatewayv2.New(opts.Session)
+	var resources []resource.Resource
 
 	params := &apigatewayv2.GetApisInput{
 		MaxResults: aws.String("100"),
@@ -41,6 +49,7 @@ func ListAPIGatewayV2APIs(sess *session.Session) ([]Resource, error) {
 				name:         item.Name,
 				protocolType: item.ProtocolType,
 				version:      item.Version,
+				createdDate:  item.CreatedDate,
 				tags:         item.Tags,
 			})
 		}
@@ -55,8 +64,17 @@ func ListAPIGatewayV2APIs(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *APIGatewayV2API) Remove() error {
+type APIGatewayV2API struct {
+	svc          *apigatewayv2.ApiGatewayV2
+	v2APIID      *string
+	name         *string
+	protocolType *string
+	version      *string
+	createdDate  *time.Time
+	tags         map[string]*string
+}
 
+func (f *APIGatewayV2API) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteApi(&apigatewayv2.DeleteApiInput{
 		ApiId: f.v2APIID,
 	})
@@ -77,6 +95,7 @@ func (f *APIGatewayV2API) Properties() types.Properties {
 		Set("APIID", f.v2APIID).
 		Set("Name", f.name).
 		Set("ProtocolType", f.protocolType).
-		Set("Version", f.version)
+		Set("Version", f.version).
+		Set("CreatedDate", f.createdDate.Format(time.RFC3339))
 	return properties
 }
