@@ -1,8 +1,13 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws/session"
+	"context"
+
 	"github.com/aws/aws-sdk-go/service/appstream"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
 )
 
 type AppStreamStack struct {
@@ -10,13 +15,24 @@ type AppStreamStack struct {
 	name *string
 }
 
+const AppStreamStackResource = "AppStreamStack"
+
 func init() {
-	register("AppStreamStack", ListAppStreamStacks)
+	registry.Register(&registry.Registration{
+		Name:     AppStreamStackResource,
+		Scope:    nuke.Account,
+		Resource: &AppStreamStack{},
+		Lister:   &AppStreamStackLister{},
+	})
 }
 
-func ListAppStreamStacks(sess *session.Session) ([]Resource, error) {
-	svc := appstream.New(sess)
-	resources := []Resource{}
+type AppStreamStackLister struct{}
+
+func (l *AppStreamStackLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := appstream.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &appstream.DescribeStacksInput{}
 
@@ -43,8 +59,7 @@ func ListAppStreamStacks(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *AppStreamStack) Remove() error {
-
+func (f *AppStreamStack) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteStack(&appstream.DeleteStackInput{
 		Name: f.name,
 	})
