@@ -1,24 +1,41 @@
 package resources
 
 import (
+	"context"
 	"fmt"
+	"time"
+
+	"github.com/gotidy/ptr"
 
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/ec2"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/awsutil"
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type EC2NATGateway struct {
-	svc   *ec2.EC2
-	natgw *ec2.NatGateway
-}
+const EC2NATGatewayResource = "EC2NATGateway"
 
 func init() {
-	register("EC2NATGateway", ListEC2NATGateways)
+	registry.Register(&registry.Registration{
+		Name:     EC2NATGatewayResource,
+		Scope:    nuke.Account,
+		Resource: &EC2NATGateway{},
+		Lister:   &EC2NATGatewayLister{},
+		DeprecatedAliases: []string{
+			"EC2NatGateway",
+		},
+	})
 }
 
-func ListEC2NATGateways(sess *session.Session) ([]Resource, error) {
-	svc := ec2.New(sess)
+type EC2NATGatewayLister struct{}
+
+func (l *EC2NATGatewayLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+	svc := ec2.New(opts.Session)
 
 	params := &ec2.DescribeNatGatewaysInput{}
 	resp, err := svc.DescribeNatGateways(params)
@@ -26,7 +43,7 @@ func ListEC2NATGateways(sess *session.Session) ([]Resource, error) {
 		return nil, err
 	}
 
-	resources := make([]Resource, 0)
+	resources := make([]resource.Resource, 0)
 	for _, natgw := range resp.NatGateways {
 		resources = append(resources, &EC2NATGateway{
 			svc:   svc,
@@ -37,14 +54,19 @@ func ListEC2NATGateways(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
+type EC2NATGateway struct {
+	svc   *ec2.EC2
+	natgw *ec2.NatGateway
+}
+
 func (n *EC2NATGateway) Filter() error {
-	if *n.natgw.State == "deleted" {
+	if *n.natgw.State == awsutil.StateDeleted {
 		return fmt.Errorf("already deleted")
 	}
 	return nil
 }
 
-func (n *EC2NATGateway) Remove() error {
+func (n *EC2NATGateway) Remove(_ context.Context) error {
 	params := &ec2.DeleteNatGatewayInput{
 		NatGatewayId: n.natgw.NatGatewayId,
 	}
@@ -59,6 +81,7 @@ func (n *EC2NATGateway) Remove() error {
 
 func (n *EC2NATGateway) Properties() types.Properties {
 	properties := types.NewProperties()
+	properties.Set("CreateTime", n.natgw.CreateTime.Format(time.RFC3339))
 	for _, tagValue := range n.natgw.Tags {
 		properties.SetTag(tagValue.Key, tagValue.Value)
 	}
@@ -66,5 +89,5 @@ func (n *EC2NATGateway) Properties() types.Properties {
 }
 
 func (n *EC2NATGateway) String() string {
-	return *n.natgw.NatGatewayId
+	return ptr.ToString(n.natgw.NatGatewayId)
 }
