@@ -1,23 +1,36 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/ssm"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type SSMDocument struct {
-	svc  *ssm.SSM
-	name *string
-}
+const SSMDocumentResource = "SSMDocument"
 
 func init() {
-	register("SSMDocument", ListSSMDocuments)
+	registry.Register(&registry.Registration{
+		Name:     SSMDocumentResource,
+		Scope:    nuke.Account,
+		Resource: &SSMDocument{},
+		Lister:   &SSMDocumentLister{},
+	})
 }
 
-func ListSSMDocuments(sess *session.Session) ([]Resource, error) {
-	svc := ssm.New(sess)
-	resources := []Resource{}
+type SSMDocumentLister struct{}
+
+func (l *SSMDocumentLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := ssm.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	documentKeyFilter := []*ssm.DocumentKeyValuesFilter{
 		{
@@ -41,6 +54,7 @@ func ListSSMDocuments(sess *session.Session) ([]Resource, error) {
 			resources = append(resources, &SSMDocument{
 				svc:  svc,
 				name: documentIdentifier.Name,
+				tags: documentIdentifier.Tags,
 			})
 		}
 
@@ -54,8 +68,13 @@ func ListSSMDocuments(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *SSMDocument) Remove() error {
+type SSMDocument struct {
+	svc  *ssm.SSM
+	name *string
+	tags []*ssm.Tag
+}
 
+func (f *SSMDocument) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteDocument(&ssm.DeleteDocumentInput{
 		Name: f.name,
 	})
@@ -63,6 +82,15 @@ func (f *SSMDocument) Remove() error {
 	return err
 }
 
+func (f *SSMDocument) Properties() types.Properties {
+	properties := types.NewProperties()
+	for _, tagValue := range f.tags {
+		properties.SetTag(tagValue.Key, tagValue.Value)
+	}
+	properties.Set("Name", f.name)
+	return properties
+}
+
 func (f *SSMDocument) String() string {
 	return *f.name
 }
